@@ -52,11 +52,11 @@ class HamiltonianResultsContainer(OrderedDict):
 
     def __init__(self, dict_file=None, data_dir=None):
         """ input:
-           dict file - 1. ethier None to create an empty results hamilitoninan as
+           dict file - 1. ethier None to create an empty results hamiltonian as
                        as was done in the original code
 
                        2. or a string with the name of the file where the file of the
-                       previously saved HamiltonianResultsContainer instatnce we wish
+                       previously saved HamiltonianResultsContainer instance we wish
                        to load
 
                        3. or an existing instance of a dict class which will be
@@ -157,7 +157,7 @@ class HamiltonianResultsContainer(OrderedDict):
 
         QUANTITIES:
             `f_0`  : HFSS Frequencies
-            `f_1`  : Analyutical first order PT on the p=4 term of the cosine
+            `f_1`  : Analytical first order PT on the p=4 term of the cosine
             `f_ND` : Numerically diagonalized
             `chi_O1`: chi matrix from 1st order PT
 
@@ -169,7 +169,7 @@ class HamiltonianResultsContainer(OrderedDict):
             vs {str} -- Swept against (default: {'variation'})
             to_dataframe {bool} -- convert or not the result to dataframe.
                          Make sure to call only if it can be converted to a DataFrame or can
-                         be concatinated into a multi-index DataFrame
+                         be concatenated into a multi-index DataFrame
 
         Returns:
             [type] -- [description]
@@ -192,7 +192,7 @@ class HamiltonianResultsContainer(OrderedDict):
             z = sort_df_col(pd.DataFrame(z))
             if self.sort_index:
                 z = self._do_sort_index(z)
-            z.index.name = 'eigenmode'
+            # z.index.name = 'eigenmode'
             z.columns.name = vs
 
         return z
@@ -265,7 +265,7 @@ class QuantumAnalysis(object):
         self.convergence = results['convergence']
         self.convergence_f_pass = results['convergence_f_pass']
 
-        self.n_modes = len(self.modes['0'])
+        self.n_modes = len(self.modes[self.variations[0]])
         self._renorm_pj = config.epr.renorm_pj
 
         # Unique variation params -- make a get function
@@ -445,9 +445,9 @@ class QuantumAnalysis(object):
 
         Specific params:
         --------------------
-            variations : None returns all_variations otherwis this is a list with number
+            variations : None returns all_variations otherwise this is a list with number
                          as strings ['0', '1']
-            nalyze_previous :set to true if you wish to overwrite previous analysis
+            analyze_previous :set to true if you wish to overwrite previous analysis
         '''
 
         result = OrderedDict()
@@ -461,6 +461,7 @@ class QuantumAnalysis(object):
             else:
                 result[variation] = self.analyze_variation(variation, **kwargs)
 
+
         self.results.save()
 
         return result
@@ -548,7 +549,7 @@ class QuantumAnalysis(object):
         if np.any(Pm < 0.0):
             print_color("  ! Warning:  Some p_mj was found <= 0. This is probably a numerical error,'\
                 'or a super low-Q mode.  We will take the abs value.  Otherwise, rerun with more precision,'\
-                'inspect, and do due dilligence.)")
+                'inspect, and do due diligence.)")
             print(Pm, '\n')
             Pm = np.abs(Pm)
 
@@ -567,7 +568,7 @@ class QuantumAnalysis(object):
             :Om: Omega_mm matrix (in GHz) (\hbar = 1) Not radians.
             :EJ: E_jj matrix of Josephson energies (in same units as hbar omega matrix)
             :PHI_zpf: ZPFs in units of \phi_0 reduced flux quantum
-            :PJ_cap: capactive particiaption matrix
+            :PJ_cap: capacitive participation matrix
 
             Return all as *np.array*
                 PM, SIGN, Om, EJ, Phi_ZPF
@@ -599,13 +600,13 @@ class QuantumAnalysis(object):
         return PJ, SJ, Om, EJ, PHI_zpf, PJ_cap, n_zpf                 # All as np.array
 
     def analyze_variation(self,
-                          variation: List[str],
+                          variation: str,
                           cos_trunc: int = None,
                           fock_trunc: int = None,
                           print_result: bool = True,
                           junctions: List = None,
                           modes: List = None):
-        # TODO avoide analyzing a previously analyzed variation
+        # TODO avoid analyzing a previously analyzed variation
         '''
         Core analysis function to call!
 
@@ -620,10 +621,10 @@ class QuantumAnalysis(object):
         ----------------
             f_0 [MHz]    : Eigenmode frequencies computed by HFSS; i.e., linear freq returned in GHz
             f_1 [MHz]    : Dressed mode frequencies (by the non-linearity; e.g., Lamb shift, etc. ).
-                           If numerical diagonalizaiton is run, then we return the numerically diagonalizaed
-                           frequencies, otherwise, use 1st order pertuirbation theory on the 4th order
+                           Result based on 1st order perturbation theory on the 4th order
                            expansion of the cosine.
-            f_ND [MHz]   : Numerical diagonalizaiton
+            f_ND [MHz]   : Numerical diagonalization result of dressed mode frequencies.
+                           only available if `cos_trunc` and  `fock_trunc` are set (non None).
             chi_O1 [MHz] : Analytic expression for the chis based on a cos trunc to 4th order, and using 1st
                            order perturbation theory. Diag is anharmonicity, off diag is full cross-Kerr.
             chi_ND [MHz] : Numerically diagonalized chi matrix. Diag is anharmonicity, off diag is full
@@ -637,10 +638,9 @@ class QuantumAnalysis(object):
             modes = list(range(self.n_modes))
         
         tmp_n_modes = self.n_modes
-        tmp_modes =self.modes[variation]
+        tmp_modes = self.modes[variation]
         self.n_modes = len(modes)
-        self.modes[variation]= modes
-    
+        self.modes[variation] = modes
 
         if (fock_trunc is None) or (cos_trunc is None):
             fock_trunc = cos_trunc = None
@@ -668,10 +668,10 @@ class QuantumAnalysis(object):
 
         if modes is not None:
             freqs_hfss = freqs_hfss[range(len(self.modes[variation])), ]
-            PJ = PJ[modes, :]
-            SJ = SJ[modes, :]
-            Om = Om[modes, :][:, modes]
-            PHI_zpf = PHI_zpf[modes, :]
+            PJ = PJ[range(len(modes)), :]
+            SJ = SJ[range(len(modes)), :]
+            Om = Om[range(len(modes)), :][:, range(len(modes))]
+            PHI_zpf = PHI_zpf[range(len(modes)), :]
             PJ_cap = PJ_cap[:, junctions]
 
         # Analytic 4-th order
@@ -691,8 +691,7 @@ class QuantumAnalysis(object):
             f1_ND, CHI_ND = None, None
 
         result = OrderedDict()
-        result['f_0'] = self.freqs_hfss[variation][modes] * \
-            1E3  # MHz - obtained directly from HFSS
+        result['f_0'] = self.freqs_hfss[variation][modes] * 1E3  # MHz - obtained directly from HFSS
         result['f_1'] = pd.Series(f1s)*1E3     # MHz
         result['f_ND'] = pd.Series(f1_ND)*1E-6  # MHz
         result['chi_O1'] = pd.DataFrame(CHI_O1)
@@ -731,18 +730,19 @@ class QuantumAnalysis(object):
             self.print_variation(variation)
             self.print_result(result)
     
-        self.n_modes = tmp_n_modes #TODO is this smart should consider defining the modes of intrest in the initilazaition of the quantum object
+        self.n_modes = tmp_n_modes # TODO is this smart should consider defining the modes of intrest in the initilazaition of the quantum object
         self.modes[variation]=tmp_modes 
         return result
+
     def full_report_variations(self, var_list: list=None):
         """see full_variation_report"""
         if var_list is None: var_list =self.variations
         for variation in var_list: 
             self.full_variation_report(variation)
     
-    def full_variation_report(self,variation):
+    def full_variation_report(self, variation):
         """
-        prints the results and paramters of a specific variation
+        prints the results and parameters of a specific variation
 
         Parameters
         ----------
@@ -757,8 +757,7 @@ class QuantumAnalysis(object):
         self.print_variation(variation)
         
         self.print_result(variation)
-        
-        
+
     def print_variation(self, variation):
         """
         Utility reporting function
@@ -782,7 +781,7 @@ class QuantumAnalysis(object):
         """
         if type(result) is str or type(result) is int: result = self.results[str(result)]
 
-        # TODO: actually make into dataframe with mode labela and junction labels
+        # TODO: actually make into dataframe with mode labels and junction labels
         pritm = lambda x, frmt="{:9.2g}": print_matrix(x, frmt=frmt)
 
         print('*** P (participation matrix, normalized.)')
@@ -834,7 +833,7 @@ class QuantumAnalysis(object):
         """Plot results versus variation
 
         Keyword Arguments:
-            swp_variable {str} -- Variable against which we swept. If noen, then just
+            swp_variable {str} -- Variable against which we swept. If none, then just
                                     take the variation index (default: {None})
             variations {list} -- [description] (default: {None})
             fig {[type]} -- [description] (default: {None})
@@ -842,7 +841,6 @@ class QuantumAnalysis(object):
         Returns:
             fig, axs
         """
-
         x_label = x_label or swp_variable
 
         # Create figure and axes
@@ -852,13 +850,13 @@ class QuantumAnalysis(object):
             axs = fig.axs
 
         ############################################################################
-        ### Axis: Frequencies
+        # Axis: Frequencies
         f0 = self.results.get_frequencies_HFSS(
-            variations=variations, vs=swp_variable).transpose()
+            variations=variations, vs=swp_variable).transpose().sort_index(key=lambda x : x.astype(int))
         f1 = self.results.get_frequencies_O1(
-            variations=variations, vs=swp_variable).transpose()
+            variations=variations, vs=swp_variable).transpose().sort_index(key=lambda x : x.astype(int))
         f_ND = self.results.get_frequencies_ND(
-            variations=variations, vs=swp_variable).transpose()
+            variations=variations, vs=swp_variable).transpose().sort_index(key=lambda x : x.astype(int))
         # changed by Asaf from f0 as not all modes are always analyzed
         mode_idx = list(f1.columns)
         n_modes = len(mode_idx)
@@ -866,7 +864,7 @@ class QuantumAnalysis(object):
         ax = axs[0, 0]
         ax.set_title('Modal frequencies (MHz)')
 
-        # TODO: shouldmove these kwargs to the config
+        # TODO: should move these kwargs to the config
         cmap = cmap_discrete(n_modes)
         kw = dict(ax=ax, color=cmap, legend=False, lw=0, ms=0)
 
@@ -886,27 +884,28 @@ class QuantumAnalysis(object):
         plt_me_line.plot(**{**kw, **dict(lw=1, alpha=0.6, color='grey')})
 
         ############################################################################
-        # Axis: Quality factors'
+        # Axis: Quality factors
         Qs = self.get_quality_factors(swp_variable=swp_variable)
         Qs = Qs if variations is None else Qs[variations]
-        Qs = Qs.transpose()
+        Qs = Qs.transpose().sort_index(key=lambda x : x.astype(int))
 
         ax = axs[1, 0]
         ax.set_title('Quality factors')
         Qs.plot(ax=ax, lw=0, marker=markerf1, ms=4,
                 legend=True, zorder=20, color=cmap)
         Qs.plot(ax=ax, lw=1, alpha=0.2, color='grey', legend=False)
-        ax.set_yscale('log')
+        if not (len(Qs) == 0): 
+          ax.set_yscale('log')
 
         ############################################################################
-        ### Axis: Alpha and chi
+        # Axis: Alpha and chi
 
         axs[0][1].set_title('Anharmonicities (MHz)')
         axs[1][1].set_title('Cross-Kerr frequencies (MHz)')
 
         def plot_chi_alpha(chi, primary):
             """
-            Intenral function to plot chi and then also to plot alpha
+            Internal function to plot chi and then also to plot alpha
             """
             idx = pd.IndexSlice
             kw1 = dict(lw=0, ms=4,  marker='o' if primary else 'x')
@@ -916,6 +915,7 @@ class QuantumAnalysis(object):
             ax = axs[0, 1]
             for i, mode in enumerate(mode_idx):  # mode index number, mode index
                 alpha = chi.loc[idx[:, mode], mode].unstack(1)
+                alpha.columns = [mode]
                 alpha.plot(ax=ax, label=mode, color=cmap[i], **kw1)
                 if primary:
                     alpha.plot(ax=ax, **kw2)
@@ -928,15 +928,12 @@ class QuantumAnalysis(object):
                 for i, mode2 in enumerate(mode_idx):
                     if int(mode2) > int(mode):
                         chi_element = chi.loc[idx[:, mode], mode2].unstack(1)
-                        chi_element.plot(
-                            ax=ax, label=f"{mode},{mode2}", color=cmap[i], **kw1)
-
+                        chi_element.plot(ax=ax, label=f"{mode},{mode2}", color=cmap[i], **kw1)
                         if primary:
                             chi_element.plot(ax=ax, **kw2)
 
         def do_legends():
-            legend_translucent(axs[0][1],  leg_kw=dict(
-                fontsize=7, title='Mode'))
+            legend_translucent(axs[0][1],  leg_kw=dict(fontsize=7, title='Mode'))
             legend_translucent(axs[1][1],  leg_kw=dict(fontsize=7))
 
         chiO1 = self.get_chis(variations=variations,
@@ -1004,7 +1001,7 @@ class QuantumAnalysis(object):
             index: eigenmode label
             columns: variation label
         """
-        label = 'f_1' if numeric else 'f_ND'
+        label = 'f_ND' if numeric else 'f_1'
         return self.results.vs_variations(label, vs=swp_variable, to_dataframe=True, variations=variations)
 
     def get_quality_factors(self, swp_variable='variation', variations: list = None):
